#!/bin/bash -x
# ============LICENSE_START=======================================================
#  Copyright (C) 2020 The Nordix Foundation. All rights reserved.
# ================================================================================
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# SPDX-License-Identifier: Apache-2.0
# ============LICENSE_END=========================================================
set -o nounset
set -o errexit

TEMP=$1
SERVERFQDN="${TEMP:-"engine.local"}"
TEMP=$2
TMPDIR="${TEMP:-"/tmp"}"

# get list of existing "local" images
docker images --format '{{ .Repository }}':'{{ .Tag  }}'" "'{{ .ID }}' | grep -v 'argv[0]\|<none>' | grep  "$SERVERFQDN" | sort > "$TMPDIR"/existinglocal_list.txt

# get list of all non "local" images
docker images --format '{{ .Repository }}':'{{ .Tag  }}'" "'{{ .ID }}' | grep -v 'argv[0]\|<none>' | grep -v "$SERVERFQDN" > "$TMPDIR"/imagenonlocal_list.txt
sed -i 's/^[a-zA-Z0-9:\.]*.io\///g' "$TMPDIR"/imagenonlocal_list.txt
sed -i 's/^[a-zA-Z0-9:\.]*onap.org:10001\///g' "$TMPDIR"/imagenonlocal_list.txt
# prepend the SERVERFQDN to the tag
awk -v VAR="$SERVERFQDN" '{print VAR"/"$0}' "$TMPDIR"/imagenonlocal_list.txt | sort > "$TMPDIR"/newimage_list.txt

# find the new entries
comm -23 "$TMPDIR"/newimage_list.txt "$TMPDIR"/existinglocal_list.txt > "$TMPDIR"/onlynewdocker_list.txt
# find how many new entries
NEWENTRIES=$(wc -l <  "$TMPDIR"/onlynewdocker_list.txt )
if [[ $NEWENTRIES -gt 0 ]]
then
  # tag the new entries
  awk '{print $2 " " $1 }' "$TMPDIR"/onlynewdocker_list.txt  | xargs -n 2 --max-procs=1 docker tag
  # push the new entries in parallel
  awk '{print $1  }' "$TMPDIR"/onlynewdocker_list.txt  |  xargs -n 1 --max-procs=4 docker push
fi
